@@ -11,7 +11,7 @@ our @ISA = qw(Exporter);
 our @EXPORT = qw( GetFileVersion );
 our @EXPORT_OK = qw(  );
 
-our $VERSION = '0.02';
+our $VERSION = '0.04';
 XSLoader::load('Win32::File::Ver', $VERSION);
 
 1;
@@ -33,6 +33,8 @@ Win32::File::Ver - Read program version information on Win32
 
 =head1 ABSTRACT
 
+Name changed to Win32::File::VersionInfo. Please use that instead!
+
 Win32::File::Ver - Perl extension for reading the version information resource 
 from files in the Microsoft Portable Executable (PE) format ( including
 programs, DLLs, fonts, drivers, etc. ).  
@@ -82,7 +84,7 @@ Possible flags are:
 
 =item OS
 
-A two part string separated by a slash (e.g. "NT/Windows 32"). The first part
+A two part string separated by a slash (e.g. "NT/Win32"). The first part
 can be one of:
 
 =over
@@ -251,8 +253,6 @@ S<"English (United States)">.
 
 =back
 
-For some examples, see the output of `make test`.
-
 Realistically, almost nothing ever uses this information, and the only thing that
 writes it is the linker that created the PE file in the first place. The only
 reason you'd want this information is if you're terminaly curious or you're writing
